@@ -54,11 +54,12 @@ class DeepTile:
 
         job = Job(tiles, 'process', locals())
 
-        nonempty_indices = tiles[0].profile.nonempty_indices
-        nonempty_tiles = [[ts[nonempty_index] for nonempty_index in nonempty_indices] for ts in tiles]
+        profile = job.profile
+        nonempty_indices = profile.nonempty_indices
+        nonempty_tiles = [ts.nonempty_tiles for ts in tiles]
 
         output_type = utils.to_tuple(func_process.output_type)
-        processed_tiles = [np.empty_like(tiles[0]) for _ in range(len(output_type))]
+        processed_tiles = [np.empty(profile.tiling, dtype=object) for _ in range(len(output_type))]
 
         if batch_axis is not None:
             batch_axis_len = nonempty_tiles[0][0].shape[batch_axis]
@@ -182,48 +183,6 @@ class DeepTile:
         if func.algorithm_type != job_type:
             raise TypeError(f"func_{job_type} has the incorrect algorithm type of {func.algorithm_type}.")
 
-    @staticmethod
-    def _create_profile_kwargs(tiling, tile_size, overlap, slices,
-                               nonempty_indices, tile_indices, border_indices):
-
-        """ (For internal use) Create profile keyword arguments.
-
-        Parameters
-        ----------
-            tiling : tuple
-                Number of tiles in each dimension.
-            tile_size : tuple
-                Size of each tile.
-            overlap : tuple
-                Fractions of ``tile_size`` to use for overlap.
-            slices : tuple or int
-                Slices to be extracted.
-            nonempty_indices : tuple
-                Indices of nonempty tiles.
-            tile_indices : tuple
-                Indices of tiles.
-            border_indices : tuple
-                Indices of borders at the middle of tile overlaps.
-
-        Returns
-        -------
-            profile_kwargs : dict
-                Profile keyword arguments.
-
-        """
-
-        profile_kwargs = {
-            'tiling': tiling,
-            'tile_size': tile_size,
-            'overlap': overlap,
-            'slices': slices,
-            'nonempty_indices': nonempty_indices,
-            'tile_indices': tile_indices,
-            'border_indices': border_indices,
-        }
-
-        return profile_kwargs
-
 
 class DeepTileArray(DeepTile):
 
@@ -268,9 +227,7 @@ class DeepTileArray(DeepTile):
         tiles = utils.pad_tiles(tiles, tile_size, tile_indices)
         nonempty_indices = utils.get_nonempty_indices(tiles)
 
-        profile_kwargs = self._create_profile_kwargs(tiling, tile_size, overlap, slices,
-                                                     nonempty_indices, tile_indices, border_indices)
-        profile = Profile(self, **profile_kwargs)
+        profile = Profile(self, tiling, tile_size, overlap, slices, nonempty_indices, tile_indices, border_indices)
         job = Job(self.image, 'get_tiles', locals(), profile)
         tiles = Tiled(tiles, job, 'tiled_image')
 
@@ -319,9 +276,7 @@ class DeepTileLargeImage(DeepTile):
         tiles = utils.pad_tiles(tiles, tile_size, tile_indices)
         nonempty_indices = utils.get_nonempty_indices(tiles)
 
-        profile_kwargs = self._create_profile_kwargs(tiling, tile_size, overlap, slices,
-                                                     nonempty_indices, tile_indices, border_indices)
-        profile = Profile(self, **profile_kwargs)
+        profile = Profile(self, tiling, tile_size, overlap, slices, nonempty_indices, tile_indices, border_indices)
         job = Job(self.image, 'get_tiles', locals(), profile)
         tiles = Tiled(tiles, job, 'tiled_image')
 
@@ -369,9 +324,7 @@ class DeepTileND2(DeepTile):
         _, tile_indices, border_indices = utils.calculate_indices(self.image_shape, tile_size, overlap)
         nonempty_indices = utils.get_nonempty_indices(tiles)
 
-        profile_kwargs = self._create_profile_kwargs(tiling, tile_size, overlap, slices,
-                                                     nonempty_indices, tile_indices, border_indices)
-        profile = Profile(self, **profile_kwargs)
+        profile = Profile(self, tiling, tile_size, overlap, slices, nonempty_indices, tile_indices, border_indices)
         job = Job(self.image, 'get_tiles', locals(), profile)
         tiles = Tiled(tiles, job, 'tiled_image')
 
